#[repr(transparent)]pub struct ViewRenderNodeKey(KeyData);Tuple Fields
0: KeyDataTrait Implementations
Sourceimpl Clone for ViewRenderNodeKey
impl Clone for ViewRenderNodeKey
Sourcefn clone(&self) -> ViewRenderNodeKey
fn clone(&self) -> ViewRenderNodeKey
Returns a duplicate of the value. Read more
1.0.0fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ViewRenderNodeKey
impl Debug for ViewRenderNodeKey
Sourceimpl Default for ViewRenderNodeKey
impl Default for ViewRenderNodeKey
Sourcefn default() -> ViewRenderNodeKey
fn default() -> ViewRenderNodeKey
Returns the “default value” for a type. Read more
Sourceimpl From<KeyData> for ViewRenderNodeKey
impl From<KeyData> for ViewRenderNodeKey
Sourceimpl Hash for ViewRenderNodeKey
impl Hash for ViewRenderNodeKey
Sourceimpl Key for ViewRenderNodeKey
impl Key for ViewRenderNodeKey
Sourcefn null() -> Self
fn null() -> Self
Creates a new key that is always invalid and distinct from any non-null
key. A null key can only be created through this method (or default
initialization of keys made with
new_key_type!, which calls this
method). Read moreSourceimpl Ord for ViewRenderNodeKey
impl Ord for ViewRenderNodeKey
Sourceimpl PartialEq for ViewRenderNodeKey
impl PartialEq for ViewRenderNodeKey
Sourceimpl PartialOrd for ViewRenderNodeKey
impl PartialOrd for ViewRenderNodeKey
impl Copy for ViewRenderNodeKey
impl Eq for ViewRenderNodeKey
impl StructuralPartialEq for ViewRenderNodeKey